# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .. import core
from ..core.request_options import RequestOptions
from ..types.speech_to_text_chunk_response_model import SpeechToTextChunkResponseModel
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.speech_to_text_stream_response_model import SpeechToTextStreamResponseModel
import json
from ..errors.bad_request_error import BadRequestError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SpeechToTextClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def convert(
        self,
        *,
        model_id: str,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpeechToTextChunkResponseModel:
        """
        Transcribe an audio or video file.

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' is available.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 31. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpeechToTextChunkResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.speech_to_text.convert(
            model_id="model_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/speech-to-text",
            method="POST",
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SpeechToTextChunkResponseModel,
                    construct_type(
                        type_=SpeechToTextChunkResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def convert_as_stream(
        self,
        *,
        model_id: str,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[SpeechToTextStreamResponseModel]:
        """
        Transcribe an audio or video file with streaming response. Returns chunks of transcription as they become available, with each chunk separated by double newlines (\n\n).

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' is available.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 31. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[SpeechToTextStreamResponseModel]
            Stream of transcription chunks

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        response = client.speech_to_text.convert_as_stream(
            model_id="model_id",
        )
        for chunk in response:
            yield chunk
        """
        with self._client_wrapper.httpx_client.stream(
            "v1/speech-to-text/stream",
            method="POST",
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    for _text in _response.iter_lines():
                        try:
                            if len(_text) == 0:
                                continue
                            yield typing.cast(
                                SpeechToTextStreamResponseModel,
                                construct_type(
                                    type_=SpeechToTextStreamResponseModel,  # type: ignore
                                    object_=json.loads(_text),
                                ),
                            )
                        except:
                            pass
                    return
                _response.read()
                if _response.status_code == 400:
                    raise BadRequestError(
                        typing.cast(
                            typing.Optional[typing.Any],
                            construct_type(
                                type_=typing.Optional[typing.Any],  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncSpeechToTextClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def convert(
        self,
        *,
        model_id: str,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SpeechToTextChunkResponseModel:
        """
        Transcribe an audio or video file.

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' is available.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 31. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SpeechToTextChunkResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.speech_to_text.convert(
                model_id="model_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/speech-to-text",
            method="POST",
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    SpeechToTextChunkResponseModel,
                    construct_type(
                        type_=SpeechToTextChunkResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def convert_as_stream(
        self,
        *,
        model_id: str,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[SpeechToTextStreamResponseModel]:
        """
        Transcribe an audio or video file with streaming response. Returns chunks of transcription as they become available, with each chunk separated by double newlines (\n\n).

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' is available.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 31. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[SpeechToTextStreamResponseModel]
            Stream of transcription chunks

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            response = await client.speech_to_text.convert_as_stream(
                model_id="model_id",
            )
            async for chunk in response:
                yield chunk


        asyncio.run(main())
        """
        async with self._client_wrapper.httpx_client.stream(
            "v1/speech-to-text/stream",
            method="POST",
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
            },
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    async for _text in _response.aiter_lines():
                        try:
                            if len(_text) == 0:
                                continue
                            yield typing.cast(
                                SpeechToTextStreamResponseModel,
                                construct_type(
                                    type_=SpeechToTextStreamResponseModel,  # type: ignore
                                    object_=json.loads(_text),
                                ),
                            )
                        except:
                            pass
                    return
                await _response.aread()
                if _response.status_code == 400:
                    raise BadRequestError(
                        typing.cast(
                            typing.Optional[typing.Any],
                            construct_type(
                                type_=typing.Optional[typing.Any],  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .dynamic_variables_config_dynamic_variable_placeholders_value import (
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class DynamicVariablesConfig(UncheckedBaseModel):
    dynamic_variable_placeholders: typing.Optional[
        typing.Dict[str, DynamicVariablesConfigDynamicVariablePlaceholdersValue]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property import ArrayJsonSchemaProperty
from .object_json_schema_property import ObjectJsonSchemaProperty
from .tool_request_model_tool_config import ToolRequestModelToolConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic
from ..core.pydantic_utilities import update_forward_refs


class ToolRequestModel(UncheckedBaseModel):
    tool_config: ToolRequestModelToolConfig

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ArrayJsonSchemaProperty, ToolRequestModel=ToolRequestModel)
update_forward_refs(ObjectJsonSchemaProperty, ToolRequestModel=ToolRequestModel)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization,
    BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization,
    BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization,
    BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization,
    TextToSpeechStreamWithTimestampsResponse,
    TextToSpeechStreamWithTimestampsResponseAlignment,
    TextToSpeechStreamWithTimestampsResponseNormalizedAlignment,
)

__all__ = [
    "BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization",
    "BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization",
    "BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization",
    "BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization",
    "TextToSpeechStreamWithTimestampsResponse",
    "TextToSpeechStreamWithTimestampsResponseAlignment",
    "TextToSpeechStreamWithTimestampsResponseNormalizedAlignment",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TextToSpeechStreamWithTimestampsResponseNormalizedAlignment(UncheckedBaseModel):
    characters: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Array of individual characters from the normalized text
    """

    character_start_times_seconds: typing.Optional[typing.List[float]] = pydantic.Field(default=None)
    """
    Array of start times (in seconds) for each normalized character
    """

    character_end_times_seconds: typing.Optional[typing.List[float]] = pydantic.Field(default=None)
    """
    Array of end times (in seconds) for each normalized character
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property import ArrayJsonSchemaProperty
from .object_json_schema_property import ObjectJsonSchemaProperty
from .tool_response_model_tool_config import ToolResponseModelToolConfig
import typing
from .tool_response_model_dependent_agents_item import ToolResponseModelDependentAgentsItem
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ..core.pydantic_utilities import update_forward_refs


class ToolResponseModel(UncheckedBaseModel):
    id: str
    tool_config: ToolResponseModelToolConfig
    dependent_agents: typing.List[ToolResponseModelDependentAgentsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ArrayJsonSchemaProperty, ToolResponseModel=ToolResponseModel)
update_forward_refs(ObjectJsonSchemaProperty, ToolResponseModel=ToolResponseModel)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing
from .literal_json_schema_property import LiteralJsonSchemaProperty
import typing

if typing.TYPE_CHECKING:
    from .object_json_schema_property import ObjectJsonSchemaProperty
    from .array_json_schema_property import ArrayJsonSchemaProperty
ArrayJsonSchemaPropertyItems = typing.Union[
    LiteralJsonSchemaProperty, "ObjectJsonSchemaProperty", "ArrayJsonSchemaProperty"
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing_extensions
import typing
from ...core.serialization import FieldMetadata
import pydantic
from .text_to_speech_stream_with_timestamps_response_alignment import TextToSpeechStreamWithTimestampsResponseAlignment
from .text_to_speech_stream_with_timestamps_response_normalized_alignment import (
    TextToSpeechStreamWithTimestampsResponseNormalizedAlignment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TextToSpeechStreamWithTimestampsResponse(UncheckedBaseModel):
    audio_base_64: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="audio_base64")] = (
        pydantic.Field(default=None)
    )
    """
    Base64 encoded audio chunk
    """

    alignment: typing.Optional[TextToSpeechStreamWithTimestampsResponseAlignment] = None
    normalized_alignment: typing.Optional[TextToSpeechStreamWithTimestampsResponseNormalizedAlignment] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .accent import Accent
from .add_agent_secret_response_model import AddAgentSecretResponseModel
from .add_chapter_response_model import AddChapterResponseModel
from .add_knowledge_base_response_model import AddKnowledgeBaseResponseModel
from .add_project_response_model import AddProjectResponseModel
from .add_pronunciation_dictionary_response_model import AddPronunciationDictionaryResponseModel
from .add_pronunciation_dictionary_rules_response_model import AddPronunciationDictionaryRulesResponseModel
from .add_voice_ivc_response_model import AddVoiceIvcResponseModel
from .add_voice_response_model import AddVoiceResponseModel
from .age import Age
from .agent_ban import AgentBan
from .agent_call_limits import AgentCallLimits
from .agent_config import AgentConfig
from .agent_config_override import AgentConfigOverride
from .agent_config_override_config import AgentConfigOverrideConfig
from .agent_metadata_response_model import AgentMetadataResponseModel
from .agent_platform_settings import AgentPlatformSettings
from .agent_summary_response_model import AgentSummaryResponseModel
from .agent_summary_response_model_access_level import AgentSummaryResponseModelAccessLevel
from .allowlist_item import AllowlistItem
from .array_json_schema_property import ArrayJsonSchemaProperty
from .array_json_schema_property_items import ArrayJsonSchemaPropertyItems
from .asr_conversational_config import AsrConversationalConfig
from .asr_input_format import AsrInputFormat
from .asr_provider import AsrProvider
from .asr_quality import AsrQuality
from .audio_native_create_project_response_model import AudioNativeCreateProjectResponseModel
from .audio_native_edit_content_response_model import AudioNativeEditContentResponseModel
from .auth_settings import AuthSettings
from .authorization_method import AuthorizationMethod
from .ban_reason_type import BanReasonType
from .body_add_to_knowledge_base_v_1_convai_add_to_knowledge_base_post import (
    BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost,
)
from .body_add_to_knowledge_base_v_1_convai_agents_agent_id_add_to_knowledge_base_post import (
    BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost,
)
from .breakdown_types import BreakdownTypes
from .chapter_content_block_extendable_node_response_model import ChapterContentBlockExtendableNodeResponseModel
from .chapter_content_block_input_model import ChapterContentBlockInputModel
from .chapter_content_block_response_model import ChapterContentBlockResponseModel
from .chapter_content_block_response_model_nodes_item import (
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
)
from .chapter_content_block_tts_node_response_model import ChapterContentBlockTtsNodeResponseModel
from .chapter_content_input_model import ChapterContentInputModel
from .chapter_content_paragraph_tts_node_input_model import ChapterContentParagraphTtsNodeInputModel
from .chapter_content_response_model import ChapterContentResponseModel
from .chapter_response import ChapterResponse
from .chapter_snapshot_response import ChapterSnapshotResponse
from .chapter_snapshots_response import ChapterSnapshotsResponse
from .chapter_state import ChapterState
from .chapter_statistics_response import ChapterStatisticsResponse
from .chapter_with_content_response_model import ChapterWithContentResponseModel
from .chapter_with_content_response_model_state import ChapterWithContentResponseModelState
from .client_event import ClientEvent
from .client_tool_config import ClientToolConfig
from .conv_ai_new_secret_config import ConvAiNewSecretConfig
from .conv_ai_secret_locator import ConvAiSecretLocator
from .conv_ai_stored_secret_config import ConvAiStoredSecretConfig
from .conversation_charging_common_model import ConversationChargingCommonModel
from .conversation_config import ConversationConfig
from .conversation_config_client_override import ConversationConfigClientOverride
from .conversation_config_client_override_config import ConversationConfigClientOverrideConfig
from .conversation_deletion_settings import ConversationDeletionSettings
from .conversation_history_analysis_common_model import ConversationHistoryAnalysisCommonModel
from .conversation_history_evaluation_criteria_result_common_model import (
    ConversationHistoryEvaluationCriteriaResultCommonModel,
)
from .conversation_history_feedback_common_model import ConversationHistoryFeedbackCommonModel
from .conversation_history_metadata_common_model import ConversationHistoryMetadataCommonModel
from .conversation_history_transcript_common_model import ConversationHistoryTranscriptCommonModel
from .conversation_history_transcript_common_model_role import ConversationHistoryTranscriptCommonModelRole
from .conversation_history_transcript_tool_call_common_model import ConversationHistoryTranscriptToolCallCommonModel
from .conversation_history_transcript_tool_result_common_model import ConversationHistoryTranscriptToolResultCommonModel
from .conversation_initiation_client_data import ConversationInitiationClientData
from .conversation_initiation_client_data_config import ConversationInitiationClientDataConfig
from .conversation_initiation_client_data_dynamic_variables_value import (
    ConversationInitiationClientDataDynamicVariablesValue,
)
from .conversation_signed_url_response_model import ConversationSignedUrlResponseModel
from .conversation_summary_response_model import ConversationSummaryResponseModel
from .conversation_summary_response_model_status import ConversationSummaryResponseModelStatus
from .conversation_token_db_model import ConversationTokenDbModel
from .conversation_token_purpose import ConversationTokenPurpose
from .conversational_config import ConversationalConfig
from .create_agent_response_model import CreateAgentResponseModel
from .create_phone_number_response_model import CreatePhoneNumberResponseModel
from .currency import Currency
from .custom_llm import CustomLlm
from .data_collection_result_common_model import DataCollectionResultCommonModel
from .dependent_available_agent_identifier import DependentAvailableAgentIdentifier
from .dependent_available_agent_identifier_access_level import DependentAvailableAgentIdentifierAccessLevel
from .dependent_unknown_agent_identifier import DependentUnknownAgentIdentifier
from .do_dubbing_response import DoDubbingResponse
from .dubbing_media_metadata import DubbingMediaMetadata
from .dubbing_metadata_response import DubbingMetadataResponse
from .dynamic_variables_config import DynamicVariablesConfig
from .dynamic_variables_config_dynamic_variable_placeholders_value import (
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
)
from .edit_chapter_response_model import EditChapterResponseModel
from .edit_project_response_model import EditProjectResponseModel
from .embed_variant import EmbedVariant
from .evaluation_settings import EvaluationSettings
from .evaluation_success_result import EvaluationSuccessResult
from .extended_subscription_response_model_billing_period import ExtendedSubscriptionResponseModelBillingPeriod
from .extended_subscription_response_model_character_refresh_period import (
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
)
from .extended_subscription_response_model_currency import ExtendedSubscriptionResponseModelCurrency
from .feedback_item import FeedbackItem
from .fine_tuning_response import FineTuningResponse
from .fine_tuning_response_model_state_value import FineTuningResponseModelStateValue
from .gender import Gender
from .get_agent_embed_response_model import GetAgentEmbedResponseModel
from .get_agent_link_response_model import GetAgentLinkResponseModel
from .get_agent_response_model import GetAgentResponseModel
from .get_agents_page_response_model import GetAgentsPageResponseModel
from .get_chapters_response import GetChaptersResponse
from .get_conversation_response_model import GetConversationResponseModel
from .get_conversation_response_model_status import GetConversationResponseModelStatus
from .get_conversations_page_response_model import GetConversationsPageResponseModel
from .get_knowledge_base_dependent_agents_response_model import GetKnowledgeBaseDependentAgentsResponseModel
from .get_knowledge_base_dependent_agents_response_model_agents_item import (
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
)
from .get_knowledge_base_list_response_model import GetKnowledgeBaseListResponseModel
from .get_knowledge_base_response_model import GetKnowledgeBaseResponseModel
from .get_knowledge_base_response_model_access_level import GetKnowledgeBaseResponseModelAccessLevel
from .get_knowledge_base_response_model_type import GetKnowledgeBaseResponseModelType
from .get_knowledge_base_summary_response_model import GetKnowledgeBaseSummaryResponseModel
from .get_knowledge_base_summary_response_model_access_level import GetKnowledgeBaseSummaryResponseModelAccessLevel
from .get_knowledge_base_summary_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_summary_response_model_type import GetKnowledgeBaseSummaryResponseModelType
from .get_library_voices_response import GetLibraryVoicesResponse
from .get_phone_number_response_model import GetPhoneNumberResponseModel
from .get_projects_response import GetProjectsResponse
from .get_pronunciation_dictionaries_metadata_response_model import GetPronunciationDictionariesMetadataResponseModel
from .get_pronunciation_dictionary_metadata_response import GetPronunciationDictionaryMetadataResponse
from .get_speech_history_response import GetSpeechHistoryResponse
from .get_voices_response import GetVoicesResponse
from .history_alignment_response_model import HistoryAlignmentResponseModel
from .history_alignments_response_model import HistoryAlignmentsResponseModel
from .history_item import HistoryItem
from .http_validation_error import HttpValidationError
from .image_avatar import ImageAvatar
from .invoice import Invoice
from .knowledge_base_locator import KnowledgeBaseLocator
from .knowledge_base_locator_type import KnowledgeBaseLocatorType
from .language_preset import LanguagePreset
from .language_preset_translation import LanguagePresetTranslation
from .language_response import LanguageResponse
from .library_voice_response import LibraryVoiceResponse
from .library_voice_response_model_category import LibraryVoiceResponseModelCategory
from .literal_json_schema_property import LiteralJsonSchemaProperty
from .literal_json_schema_property_type import LiteralJsonSchemaPropertyType
from .llm import Llm
from .manual_verification_file_response import ManualVerificationFileResponse
from .manual_verification_response import ManualVerificationResponse
from .model import Model
from .model_rates_response_model import ModelRatesResponseModel
from .model_response_model_concurrency_group import ModelResponseModelConcurrencyGroup
from .moderation_status_response_model import ModerationStatusResponseModel
from .moderation_status_response_model_safety_status import ModerationStatusResponseModelSafetyStatus
from .moderation_status_response_model_warning_status import ModerationStatusResponseModelWarningStatus
from .object_json_schema_property import ObjectJsonSchemaProperty
from .object_json_schema_property_properties_value import ObjectJsonSchemaPropertyPropertiesValue
from .orb_avatar import OrbAvatar
from .output_format import OutputFormat
from .phone_number_agent_info import PhoneNumberAgentInfo
from .podcast_bulletin_mode import PodcastBulletinMode
from .podcast_bulletin_mode_data import PodcastBulletinModeData
from .podcast_conversation_mode import PodcastConversationMode
from .podcast_conversation_mode_data import PodcastConversationModeData
from .podcast_project_response_model import PodcastProjectResponseModel
from .podcast_text_source import PodcastTextSource
from .podcast_url_source import PodcastUrlSource
from .post_agent_avatar_response_model import PostAgentAvatarResponseModel
from .privacy_config import PrivacyConfig
from .profile_page_response_model import ProfilePageResponseModel
from .project_creation_meta_response_model import ProjectCreationMetaResponseModel
from .project_creation_meta_response_model_status import ProjectCreationMetaResponseModelStatus
from .project_creation_meta_response_model_type import ProjectCreationMetaResponseModelType
from .project_extended_response_model import ProjectExtendedResponseModel
from .project_extended_response_model_access_level import ProjectExtendedResponseModelAccessLevel
from .project_extended_response_model_apply_text_normalization import ProjectExtendedResponseModelApplyTextNormalization
from .project_extended_response_model_fiction import ProjectExtendedResponseModelFiction
from .project_extended_response_model_quality_preset import ProjectExtendedResponseModelQualityPreset
from .project_extended_response_model_target_audience import ProjectExtendedResponseModelTargetAudience
from .project_response import ProjectResponse
from .project_response_model_access_level import ProjectResponseModelAccessLevel
from .project_response_model_fiction import ProjectResponseModelFiction
from .project_response_model_target_audience import ProjectResponseModelTargetAudience
from .project_snapshot_response import ProjectSnapshotResponse
from .project_snapshot_upload_response_model import ProjectSnapshotUploadResponseModel
from .project_snapshot_upload_response_model_status import ProjectSnapshotUploadResponseModelStatus
from .project_snapshots_response import ProjectSnapshotsResponse
from .project_state import ProjectState
from .prompt_agent import PromptAgent
from .prompt_agent_override import PromptAgentOverride
from .prompt_agent_override_config import PromptAgentOverrideConfig
from .prompt_agent_tools_item import (
    PromptAgentToolsItem,
    PromptAgentToolsItem_Client,
    PromptAgentToolsItem_System,
    PromptAgentToolsItem_Webhook,
)
from .prompt_evaluation_criteria import PromptEvaluationCriteria
from .pronunciation_dictionary_alias_rule_request_model import PronunciationDictionaryAliasRuleRequestModel
from .pronunciation_dictionary_phoneme_rule_request_model import PronunciationDictionaryPhonemeRuleRequestModel
from .pronunciation_dictionary_version_locator import PronunciationDictionaryVersionLocator
from .pronunciation_dictionary_version_response_model import PronunciationDictionaryVersionResponseModel
from .pydantic_pronunciation_dictionary_version_locator import PydanticPronunciationDictionaryVersionLocator
from .query_params_json_schema import QueryParamsJsonSchema
from .reader_resource_response_model import ReaderResourceResponseModel
from .reader_resource_response_model_resource_type import ReaderResourceResponseModelResourceType
from .recording_response import RecordingResponse
from .remove_pronunciation_dictionary_rules_response_model import RemovePronunciationDictionaryRulesResponseModel
from .review_status import ReviewStatus
from .safety import Safety
from .safety_evaluation import SafetyEvaluation
from .safety_rule import SafetyRule
from .speech_history_item_response import SpeechHistoryItemResponse
from .speech_history_item_response_model_source import SpeechHistoryItemResponseModelSource
from .speech_history_item_response_model_voice_category import SpeechHistoryItemResponseModelVoiceCategory
from .speech_to_text_chunk_response_model import SpeechToTextChunkResponseModel
from .speech_to_text_stream_response_model import SpeechToTextStreamResponseModel
from .speech_to_text_word_response_model import SpeechToTextWordResponseModel
from .speech_to_text_word_response_model_type import SpeechToTextWordResponseModelType
from .subscription import Subscription
from .subscription_response import SubscriptionResponse
from .subscription_response_model_billing_period import SubscriptionResponseModelBillingPeriod
from .subscription_response_model_character_refresh_period import SubscriptionResponseModelCharacterRefreshPeriod
from .subscription_response_model_currency import SubscriptionResponseModelCurrency
from .subscription_status import SubscriptionStatus
from .system_tool_config import SystemToolConfig
from .telephony_provider import TelephonyProvider
from .text_to_speech_as_stream_request import TextToSpeechAsStreamRequest
from .tool_request_model import ToolRequestModel
from .tool_request_model_tool_config import (
    ToolRequestModelToolConfig,
    ToolRequestModelToolConfig_Client,
    ToolRequestModelToolConfig_System,
    ToolRequestModelToolConfig_Webhook,
)
from .tool_response_model import ToolResponseModel
from .tool_response_model_dependent_agents_item import (
    ToolResponseModelDependentAgentsItem,
    ToolResponseModelDependentAgentsItem_Available,
    ToolResponseModelDependentAgentsItem_Unknown,
)
from .tool_response_model_tool_config import (
    ToolResponseModelToolConfig,
    ToolResponseModelToolConfig_Client,
    ToolResponseModelToolConfig_System,
    ToolResponseModelToolConfig_Webhook,
)
from .tools_response_model import ToolsResponseModel
from .tts_conversational_config import TtsConversationalConfig
from .tts_conversational_config_override import TtsConversationalConfigOverride
from .tts_conversational_config_override_config import TtsConversationalConfigOverrideConfig
from .tts_conversational_model import TtsConversationalModel
from .tts_optimize_streaming_latency import TtsOptimizeStreamingLatency
from .tts_output_format import TtsOutputFormat
from .turn_config import TurnConfig
from .turn_mode import TurnMode
from .url_avatar import UrlAvatar
from .usage_characters_response_model import UsageCharactersResponseModel
from .user import User
from .user_feedback import UserFeedback
from .user_feedback_score import UserFeedbackScore
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .verification_attempt_response import VerificationAttemptResponse
from .voice import Voice
from .voice_generation_parameter_option_response import VoiceGenerationParameterOptionResponse
from .voice_generation_parameter_response import VoiceGenerationParameterResponse
from .voice_preview_response_model import VoicePreviewResponseModel
from .voice_previews_response_model import VoicePreviewsResponseModel
from .voice_response_model_category import VoiceResponseModelCategory
from .voice_response_model_safety_control import VoiceResponseModelSafetyControl
from .voice_sample import VoiceSample
from .voice_settings import VoiceSettings
from .voice_sharing_moderation_check_response_model import VoiceSharingModerationCheckResponseModel
from .voice_sharing_response import VoiceSharingResponse
from .voice_sharing_response_model_category import VoiceSharingResponseModelCategory
from .voice_sharing_state import VoiceSharingState
from .voice_verification_response import VoiceVerificationResponse
from .webhook_tool_api_schema_config import WebhookToolApiSchemaConfig
from .webhook_tool_api_schema_config_method import WebhookToolApiSchemaConfigMethod
from .webhook_tool_api_schema_config_request_headers_value import WebhookToolApiSchemaConfigRequestHeadersValue
from .webhook_tool_config import WebhookToolConfig
from .widget_config import WidgetConfig
from .widget_config_avatar import (
    WidgetConfigAvatar,
    WidgetConfigAvatar_Image,
    WidgetConfigAvatar_Orb,
    WidgetConfigAvatar_Url,
)
from .widget_config_response_model import WidgetConfigResponseModel
from .widget_config_response_model_avatar import (
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
)
from .widget_feedback_mode import WidgetFeedbackMode
from .workspace_group_by_name_response_model import WorkspaceGroupByNameResponseModel

__all__ = [
    "Accent",
    "AddAgentSecretResponseModel",
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryRulesResponseModel",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "Age",
    "AgentBan",
    "AgentCallLimits",
    "AgentConfig",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettings",
    "AgentSummaryResponseModel",
    "AgentSummaryResponseModelAccessLevel",
    "AllowlistItem",
    "ArrayJsonSchemaProperty",
    "ArrayJsonSchemaPropertyItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AuthSettings",
    "AuthorizationMethod",
    "BanReasonType",
    "BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost",
    "BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost",
    "BreakdownTypes",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "ClientEvent",
    "ClientToolConfig",
    "ConvAiNewSecretConfig",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverride",
    "ConversationConfigClientOverrideConfig",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryTranscriptCommonModel",
    "ConversationHistoryTranscriptCommonModelRole",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolResultCommonModel",
    "ConversationInitiationClientData",
    "ConversationInitiationClientDataConfig",
    "ConversationInitiationClientDataDynamicVariablesValue",
    "ConversationSignedUrlResponseModel",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationalConfig",
    "CreateAgentResponseModel",
    "CreatePhoneNumberResponseModel",
    "Currency",
    "CustomLlm",
    "DataCollectionResultCommonModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentUnknownAgentIdentifier",
    "DoDubbingResponse",
    "DubbingMediaMetadata",
    "DubbingMetadataResponse",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EmbedVariant",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeedbackItem",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "Gender",
    "GetAgentEmbedResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentsPageResponseModel",
    "GetChaptersResponse",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseResponseModel",
    "GetKnowledgeBaseResponseModelAccessLevel",
    "GetKnowledgeBaseResponseModelType",
    "GetKnowledgeBaseSummaryResponseModel",
    "GetKnowledgeBaseSummaryResponseModelAccessLevel",
    "GetKnowledgeBaseSummaryResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryResponseModelType",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberResponseModel",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionaryMetadataResponse",
    "GetSpeechHistoryResponse",
    "GetVoicesResponse",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItem",
    "HttpValidationError",
    "ImageAvatar",
    "Invoice",
    "KnowledgeBaseLocator",
    "KnowledgeBaseLocatorType",
    "LanguagePreset",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "ObjectJsonSchemaProperty",
    "ObjectJsonSchemaPropertyPropertiesValue",
    "OrbAvatar",
    "OutputFormat",
    "PhoneNumberAgentInfo",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PrivacyConfig",
    "ProfilePageResponseModel",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponseModel",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotResponse",
    "ProjectSnapshotUploadResponseModel",
    "ProjectSnapshotUploadResponseModelStatus",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgent",
    "PromptAgentOverride",
    "PromptAgentOverrideConfig",
    "PromptAgentToolsItem",
    "PromptAgentToolsItem_Client",
    "PromptAgentToolsItem_System",
    "PromptAgentToolsItem_Webhook",
    "PromptEvaluationCriteria",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RecordingResponse",
    "RemovePronunciationDictionaryRulesResponseModel",
    "ReviewStatus",
    "Safety",
    "SafetyEvaluation",
    "SafetyRule",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextStreamResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "Subscription",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatus",
    "SystemToolConfig",
    "TelephonyProvider",
    "TextToSpeechAsStreamRequest",
    "ToolRequestModel",
    "ToolRequestModelToolConfig",
    "ToolRequestModelToolConfig_Client",
    "ToolRequestModelToolConfig_System",
    "ToolRequestModelToolConfig_Webhook",
    "ToolResponseModel",
    "ToolResponseModelDependentAgentsItem",
    "ToolResponseModelDependentAgentsItem_Available",
    "ToolResponseModelDependentAgentsItem_Unknown",
    "ToolResponseModelToolConfig",
    "ToolResponseModelToolConfig_Client",
    "ToolResponseModelToolConfig_System",
    "ToolResponseModelToolConfig_Webhook",
    "ToolsResponseModel",
    "TtsConversationalConfig",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "UrlAvatar",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "Voice",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoicePreviewResponseModel",
    "VoicePreviewsResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "WebhookToolApiSchemaConfig",
    "WebhookToolApiSchemaConfigMethod",
    "WebhookToolApiSchemaConfigRequestHeadersValue",
    "WebhookToolConfig",
    "WidgetConfig",
    "WidgetConfigAvatar",
    "WidgetConfigAvatar_Image",
    "WidgetConfigAvatar_Orb",
    "WidgetConfigAvatar_Url",
    "WidgetConfigResponseModel",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetFeedbackMode",
    "WorkspaceGroupByNameResponseModel",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .auth_settings import AuthSettings
from .evaluation_settings import EvaluationSettings
from .widget_config import WidgetConfig
from .literal_json_schema_property import LiteralJsonSchemaProperty
from .conversation_initiation_client_data_config import ConversationInitiationClientDataConfig
from .agent_call_limits import AgentCallLimits
from .agent_ban import AgentBan
from .safety import Safety
from .privacy_config import PrivacyConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentPlatformSettings(UncheckedBaseModel):
    auth: typing.Optional[AuthSettings] = None
    evaluation: typing.Optional[EvaluationSettings] = None
    widget: typing.Optional[WidgetConfig] = None
    data_collection: typing.Optional[typing.Dict[str, LiteralJsonSchemaProperty]] = None
    overrides: typing.Optional[ConversationInitiationClientDataConfig] = None
    call_limits: typing.Optional[AgentCallLimits] = None
    ban: typing.Optional[AgentBan] = None
    safety: typing.Optional[Safety] = None
    privacy: typing.Optional[PrivacyConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property import ArrayJsonSchemaProperty
from .object_json_schema_property import ObjectJsonSchemaProperty
import typing
from .webhook_tool_api_schema_config import WebhookToolApiSchemaConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
import typing_extensions
from ..core.unchecked_base_model import UnionMetadata
from ..core.pydantic_utilities import update_forward_refs


class PromptAgentToolsItem_Webhook(UncheckedBaseModel):
    type: typing.Literal["webhook"] = "webhook"
    name: str
    description: str
    api_schema: WebhookToolApiSchemaConfig

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class PromptAgentToolsItem_Client(UncheckedBaseModel):
    type: typing.Literal["client"] = "client"
    name: str
    description: str
    parameters: typing.Optional[ObjectJsonSchemaProperty] = None
    expects_response: typing.Optional[bool] = None
    response_timeout_secs: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class PromptAgentToolsItem_System(UncheckedBaseModel):
    type: typing.Literal["system"] = "system"
    name: str
    description: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


PromptAgentToolsItem = typing_extensions.Annotated[
    typing.Union[PromptAgentToolsItem_Webhook, PromptAgentToolsItem_Client, PromptAgentToolsItem_System],
    UnionMetadata(discriminant="type"),
]
update_forward_refs(ArrayJsonSchemaProperty, PromptAgentToolsItem_Webhook=PromptAgentToolsItem_Webhook)
update_forward_refs(ObjectJsonSchemaProperty, PromptAgentToolsItem_Webhook=PromptAgentToolsItem_Webhook)
update_forward_refs(ArrayJsonSchemaProperty, PromptAgentToolsItem_Client=PromptAgentToolsItem_Client)
update_forward_refs(ObjectJsonSchemaProperty, PromptAgentToolsItem_Client=PromptAgentToolsItem_Client)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property import ArrayJsonSchemaProperty
from .object_json_schema_property import ObjectJsonSchemaProperty
import typing
from .agent_config import AgentConfig
from .asr_conversational_config import AsrConversationalConfig
from .turn_config import TurnConfig
from .tts_conversational_config import TtsConversationalConfig
from .conversation_config import ConversationConfig
from .language_preset import LanguagePreset
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ..core.pydantic_utilities import update_forward_refs


class ConversationalConfig(UncheckedBaseModel):
    agent: typing.Optional[AgentConfig] = None
    asr: typing.Optional[AsrConversationalConfig] = None
    turn: typing.Optional[TurnConfig] = None
    tts: typing.Optional[TtsConversationalConfig] = None
    conversation: typing.Optional[ConversationConfig] = None
    language_presets: typing.Optional[typing.Dict[str, LanguagePreset]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ArrayJsonSchemaProperty, ConversationalConfig=ConversationalConfig)
update_forward_refs(ObjectJsonSchemaProperty, ConversationalConfig=ConversationalConfig)



# This file was auto-generated by Fern from our API Definition.

from .types import ProjectsAddRequestApplyTextNormalization, ProjectsAddRequestFiction, ProjectsAddRequestTargetAudience

__all__ = ["ProjectsAddRequestApplyTextNormalization", "ProjectsAddRequestFiction", "ProjectsAddRequestTargetAudience"]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .tts_conversational_model import TtsConversationalModel
from .tts_output_format import TtsOutputFormat
from .tts_optimize_streaming_latency import TtsOptimizeStreamingLatency
from .pydantic_pronunciation_dictionary_version_locator import PydanticPronunciationDictionaryVersionLocator
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TtsConversationalConfig(UncheckedBaseModel):
    model_id: typing.Optional[TtsConversationalModel] = None
    voice_id: typing.Optional[str] = None
    agent_output_audio_format: typing.Optional[TtsOutputFormat] = None
    optimize_streaming_latency: typing.Optional[TtsOptimizeStreamingLatency] = None
    stability: typing.Optional[float] = None
    similarity_boost: typing.Optional[float] = None
    pronunciation_dictionary_locators: typing.Optional[typing.List[PydanticPronunciationDictionaryVersionLocator]] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
